
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ #
# PROJECT:   What drives attitudes towards the reintegration of former fighters? 
#            Insights from a conjoint experiment in Nigeria 
#             
# AUTHOR:   Paper by Amlie Godefroidt and Arnim Langer
#           R code by Amlie Godefroidt (amelie.godefroidt@gmail.com)
#           
# DATE:     Last successful replication on 24 February 2022
# 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ # 
# This R file contains the code necessary to replicate the results reported in 
#     the main article and corresponding Online Appendix of the article. 
#     
# All analyses were carried out using R version 4.0.5. on a Intel Core i5 DELL laptop
# 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ # 
# 
# 
# Clear environment and set your own working directory
rm(list=ls())
set.seed(1234)
setwd(".../GodefroidtLanger_2021_ReplicationFiles")
getwd()


##### Loading packages --------------------------------------------------------
# ipak function: install and load multiple R packages. The function first checks whether the packages are installed. If not, it installs the packages before loading everything.

ipak <- function(pkg){  new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])]
if(length(new.pkg)) install.packages(new.pkg, dependencies = TRUE)
sapply(pkg, require, character.only = TRUE)
}

packages <- c("psych", "ggplot2", "cregg", "foreign", "tidyverse", "ggpubr", "cowplot", "gridExtra", "lme4", "tidyr", "ltm", "dplyr", "gtools") 
ipak(packages)



# 1. DATA CLEANING AND DESCRIPTIVES -------------------------------------------
# loading the data
wide.data = read.spss("Reintegration_Data.sav", use.value.labels = F, to.data.frame = T)

# listwise deletion on experimental outcomes
wide.data = wide.data %>% 
  drop_na(choice_a, choice_b, choice_c,
          rating_a1, rating_a2,
          rating_b1, rating_b2,
          rating_c1, rating_c2,
          religion, gender, 
          victimization_1, worry_1, worry_2, worry_3)

# recode where necessary
wide.data$religion <- factor(wide.data$religion,
                            levels = c(1,2,3),
                            labels = c("Christian", "Muslim", "Other/No"))
wide.data$gender <- factor(wide.data$gender,
                               levels = c(1, 2),
                               labels = c("Male", "Female"))
wide.data$geopolitical_zone <- factor(wide.data$geopolitical_zone,
                               levels = c(1, 2, 3, 4, 5, 6, 88),
                               labels = c("NC", "NE", "NW", "SE", "SS", "SW", 
                                          "Not Nigeria"))
wide.data$victimization_1 <- factor(wide.data$victimization_1,
                               levels = c(0,1),
                               labels = c("No victim", "Victim"))

# Inspecting the data 
# religion
wide.data %>%
  group_by(religion) %>%
  summarise(n = n()) %>%
  mutate(freq = n / sum(n))
# gender
wide.data %>%
  group_by(gender) %>%
  summarise(n = n()) %>%
  mutate(freq = n / sum(n))
# geopolitical_zone
wide.data %>%
  group_by(geopolitical_zone) %>%
  summarise(n = n()) %>%
  mutate(freq = n / sum(n))
(0.00554+0.00605)*100
# victimization_1
wide.data %>%
  group_by(victimization_1) %>%
  summarise(n = n()) %>%
  mutate(freq = n / sum(n))
# worry
describe(wide.data$worry_mean)

# determine Cronbach's alpha for worry scale:
# get dataframe with relevant worry-items:
worry.dat <- subset(
  wide.data, 
  select = c("worry_1", "worry_2", "worry_3"))
# Cronbach's alpha:
cronbach.alpha(worry.dat)


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 2. CONJOINT EXPERIMENT ------------------------------------------------------
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# This part of code *hugely* benefitted from the scripts made available by Jens Hainmueller, Daniel Hopkins, and Teppei Yamamoto (2014), Connor Huff and Joshua D. Kertzer (2018), and Thomas Leeper, Sara B. Hobolt, and James Tilley (2019). Thanks!
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

(1984*6)/2
1984*6

## To analyze the data using cregg, we need to coerce this "wide" dataset into a "long/tidy" one.

# profile_variables
list1 <- list(
  Gender = list(
    ~ gender_a1 + gender_b1 + gender_c1,
    ~ gender_a2 + gender_b2 + gender_c2
  ),
  Age = list(
    ~ age_a1 + age_b1 + age_c1,
    ~ age_a2 + age_b2 + age_c2
  ),
  Joining = list(
    ~ joining_a1 + joining_b1 + joining_c1,
    ~ joining_a2 + joining_b2 + joining_c2
  ),
  Atrocity = list(
    ~ activity_a1 + activity_b1 + activity_c1,
    ~ activity_a2 + activity_b2 + activity_c2
  ),
  Victim = list(
    ~ victim_a1 + victim_b1 + victim_c1,
    ~ victim_a2 + victim_b2 + victim_c2
  ),
  Leaving = list(
    ~ leaving_a1 + leaving_b1 + leaving_c1,
    ~ leaving_a2 + leaving_b2 + leaving_c2
  ),
  Reconciliation = list(
    ~ reconciliation_a1 + reconciliation_b1 + reconciliation_c1,
    ~ reconciliation_a2 + reconciliation_b2 + reconciliation_c2
  ),
  rating = list(
    ~ rating_a1 + rating_b1 + rating_c1,
    ~ rating_a2 + rating_b2 + rating_c2
  ),
  amnesty = list(
    ~ amnesty_a1 + amnesty_b1 + amnesty_c1,
    ~ amnesty_a2 + amnesty_b2 + amnesty_c2
  ),
  death = list(
    ~ death_a1 + death_b1 + death_c1,
    ~ death_a2 + death_b2 + death_c2
  )
)

# task variables
list2 <- list(choice = ~ choice_a + choice_b + choice_c)

# perform reshape
reintegration.data <- cj_tidy(wide.data, profile_variables = list1, task_variables = list2, id = ~ respondent)
#stopifnot(nrow(reintegration.data) == nrow(wide.data)*3*2)

# recode outcome so it is coded sensibly
reintegration.data$chosen <- ifelse((reintegration.data$profile == "A" & reintegration.data$choice == 1) |
                        (reintegration.data$profile == "B" & reintegration.data$choice == 2), 1, 0)

# trim white space
reintegration.data$Gender <- as.factor(trimws(reintegration.data$Gender))
reintegration.data$Age <- as.factor(trimws(reintegration.data$Age))
reintegration.data$Joining <- as.factor(trimws(reintegration.data$Joining))
reintegration.data$Victim <- as.factor(trimws(reintegration.data$Victim))
reintegration.data$Atrocity <- as.factor(trimws(reintegration.data$Atrocity))
reintegration.data$Leaving <- as.factor(trimws(reintegration.data$Leaving))
reintegration.data$Reconciliation <- as.factor(trimws(reintegration.data$Reconciliation))

# preferred feature order
reintegration.data$Gender <- factor(reintegration.data$Gender, levels = c("Male", "Female"))
reintegration.data$Age <- factor(reintegration.data$Age, levels = c("30 years", "25 years", "20 years", "15 years", "10 years", "0 year"))
reintegration.data$Joining <- factor(reintegration.data$Joining, levels = c("Establishing a Caliphate", "Corruption", "Securing a livelihood", "Poverty in the North", "Forced to join"))
reintegration.data$Atrocity <- factor(reintegration.data$Atrocity, levels = c("Rape", "Killings", "Bombings", "Coordinating attacks", "Kidnappings"))
reintegration.data$Victim <- factor(reintegration.data$Victim, levels = c("Christians", "Muslims", "Civilians", "Police personnel", "Military personnel", "Government officials"))
reintegration.data$Leaving <- factor(reintegration.data$Leaving, levels = c("Captured by the military", "Injured and hospitalized", "Uncertain about survival of BH", "Disappointed in ideology of BH", "Remorse of violence"))
reintegration.data$Reconciliation <- factor(reintegration.data$Reconciliation, levels = c("No conciliatory actions undertaken", "Paid compensation to victims' family", "Followed deradicalization programme", "Offered apologies to victims' family",  "Asked forgiveness from victims' family", "Helped police and military"))

# colors for plotting
mycols <- c("black", "black", "black", "black", "black", "black", "black")



## 2.1. Main Analyses: Forced-Choice Design -----------------------------------

### 2.1.1. Individual Feature Models (Reported in the main paper...
# ... and numerically in Appendix 2.2 SI -- Model 1)

#### Gender -------------
gender <- chosen ~ Gender

# 1) descriptive modeling and plotting
chosen_mm_gender <- mm(reintegration.data, gender, id = ~respondent)
chosen_mm_gender[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_gender_plot <- plot(chosen_mm_gender,
                       feature_headers = FALSE, 
                       feature_order = c(),
                       legend_pos = "none",
                       xlim = c(0.3,0.7),
                       xlab = "Marginal mean",
                       vline = 0.5, vline_color = "black",
                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 2) causal modeling and plotting
chosen_amce_gender <- amce(reintegration.data, gender, id = ~respondent)
chosen_amce_gender[c("level", "estimate", "std.error", "p")]
#jpeg("amce_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_gender_plot <- plot(chosen_amce_gender,
                         feature_headers = FALSE, 
                         feature_order = c(),
                         legend_pos = "none",
                         xlim = c(-0.05,0.3),
                         xlab = "Average marginal component effect",
                         vline = 0.0, vline_color = "black",
                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 3) Combine AMCE and MM plot 
grid.arrange(amce_gender_plot, mm_gender_plot, ncol=2)


#### Age -------------
age <- chosen ~ Age

# descriptive modeling and plotting
chosen_mm_age <- mm(reintegration.data, age, id = ~respondent)
chosen_mm_age[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_age_plot <- plot(chosen_mm_age,
                    feature_headers = FALSE, 
                    feature_order = c(),
                    legend_pos = "none",
                    xlim = c(0.3,0.7),
                    xlab = "Marginal mean",
                    vline = 0.5, vline_color = "black",
                    size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
chosen_amce_age <- amce(reintegration.data, age, id = ~respondent)
chosen_amce_age[c("level", "estimate", "std.error", "p")]
#jpeg("amce_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_age_plot <- plot(chosen_amce_age,
                      feature_headers = FALSE, 
                      feature_order = c(),
                      legend_pos = "none",
                      xlim = c(-0.05,0.3),
                      xlab = "Average marginal component effect",
                      vline = 0.0, vline_color = "black",
                      size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_age_plot, mm_age_plot, ncol=2)


#### Reason for joining -------------
joining <- chosen ~ Joining

# descriptive modeling and plotting
chosen_mm_joining <- mm(reintegration.data, joining, id = ~respondent)
chosen_mm_joining[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_joining_plot <- plot(chosen_mm_joining,
                        feature_headers = FALSE, 
                        feature_order = c(),
                        legend_pos = "none",
                        xlim = c(0.3,0.7),
                        xlab = "Marginal mean",
                        vline = 0.5, vline_color = "black",
                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
chosen_amce_joining <- amce(reintegration.data, joining, id = ~respondent)
head(chosen_amce_joining[c("level", "estimate", "std.error", "p")])
#jpeg("amce_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_joining_plot <- plot(chosen_amce_joining,
                          feature_headers = FALSE, 
                          feature_order = c(),
                          legend_pos = "none",
                          xlim = c(-0.05,0.3),
                          xlab = "Average marginal component effect",
                          vline = 0.0, vline_color = "black",
                          size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_joining_plot, mm_joining_plot, ncol=2)


#### Atrocity -------------
atrocity <- chosen ~ Atrocity

# descriptive modeling and plotting
chosen_mm_atrocity <- mm(reintegration.data, atrocity, id = ~respondent)
chosen_mm_atrocity[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_atrocity_plot <- plot(chosen_mm_atrocity,
                         feature_headers = FALSE, 
                         feature_order = c(),
                         legend_pos = "none",
                         xlim = c(0.3,0.7),
                         xlab = "Marginal mean",
                         vline = 0.5, vline_color = "black",
                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
chosen_amce_atrocity <- amce(reintegration.data, atrocity, id = ~respondent)
chosen_amce_atrocity[c("level", "estimate", "std.error", "p")]
#jpeg("amce_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_atrocity_plot <- plot(chosen_amce_atrocity,
                           feature_headers = FALSE, 
                           feature_order = c(),
                           legend_pos = "none",
                           xlim = c(-0.05,0.3),
                           xlab = "Average marginal component effect",
                           vline = 0.0, vline_color = "black",
                           size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_atrocity_plot, mm_atrocity_plot, ncol=2)


#### Victim/target -------------
victim <- chosen ~ Victim

# descriptive modeling and plotting
chosen_mm_victim <- mm(reintegration.data, victim, id = ~respondent)
chosen_mm_victim[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_victim_plot <- plot(chosen_mm_victim,
                       feature_headers = FALSE, 
                       feature_order = c(),
                       legend_pos = "none",
                       xlim = c(0.3,0.7),
                       xlab = "Marginal mean",
                       vline = 0.5, vline_color = "black",
                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
chosen_amce_victim <- amce(reintegration.data, victim, id = ~respondent)
chosen_amce_victim[c("level", "estimate", "std.error", "p")]
#jpeg("amce_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_victim_plot <- plot(chosen_amce_victim,
                         feature_headers = FALSE, 
                         feature_order = c(),
                         legend_pos = "none",
                         xlim = c(-0.05,0.3),
                         xlab = "Average marginal component effect",
                         vline = 0.0, vline_color = "black",
                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_victim_plot, mm_victim_plot, ncol=2)


# what about civilian vs. non-civlian targeting?
# recode intod dichotomous variable: civilians vs. non-civilians
reintegration.data$Target <- ifelse((reintegration.data$Victim == "Police personnel" | 
                                       reintegration.data$Victim == "Military personnel" | 
                                       reintegration.data$Victim == "Government officials"), 
                                    1, 0)
reintegration.data$Target = factor(reintegration.data$Target,
                            levels = c(1,0),
                            labels = c("Non-civilian", "Civilian"))
summary(reintegration.data$Target)
# fit model
target <- chosen ~ Target
# descriptive modeling and plotting
chosen_mm_target <- mm(reintegration.data, target, id = ~respondent)
chosen_mm_target[c("level", "estimate", "std.error", "lower", "upper")]
# causal modeling and plotting
chosen_amce_target <- amce(reintegration.data, target, id = ~respondent)
chosen_amce_target[c("level", "estimate", "std.error", "p")]


#### Reason for leaving -------------
leaving <- chosen ~ Leaving

# descriptive modeling and plotting
chosen_mm_leaving <- mm(reintegration.data, leaving, id = ~respondent)
chosen_mm_leaving[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_leaving_plot <- plot(chosen_mm_leaving,
                        feature_headers = FALSE, 
                        feature_order = c(),
                        legend_pos = "none",
                        xlim = c(0.3,0.7),
                        vline = 0.5, vline_color = "black",
                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
chosen_amce_leaving <- amce(reintegration.data, leaving, id = ~respondent)
chosen_amce_leaving[c("level", "estimate", "std.error", "p")]
#jpeg("amce_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_leaving_plot <- plot(chosen_amce_leaving,
                          feature_headers = FALSE, 
                          feature_order = c(),
                          legend_pos = "none",
                          xlim = c(-0.05,0.3),
                          xlab = "Average marginal component effect",
                          vline = 0.0, vline_color = "black",
                          size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_leaving_plot, mm_leaving_plot, ncol=2)


#### Conciliatory gestures -------------
reconciliation <- chosen ~ Reconciliation

# descriptive modeling and plotting
chosen_mm_reconciliation <- mm(reintegration.data, reconciliation, id = ~respondent)
chosen_mm_reconciliation[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_reconciliation_plot <- plot(chosen_mm_reconciliation,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.3,0.7),
                               xlab = "Marginal mean",
                               vline = 0.5, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()
  
# causal modeling and plotting
chosen_amce_reconciliation <- amce(reintegration.data, reconciliation, id = ~respondent)
chosen_amce_reconciliation[c("level", "estimate", "std.error", "p")]
#jpeg("amce_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_reconciliation_plot <- plot(chosen_amce_reconciliation,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(-0.05,0.3),
                                 xlab = "Average marginal component effect",
                                 vline = 0.0, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_reconciliation_plot, mm_reconciliation_plot, ncol=2)


####################### FIGURE 3 ######################
## AMCE plot
amce_age_plot_blank <- amce_age_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_joining_plot_blank <- amce_joining_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_atrocity_plot_blank <- amce_atrocity_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_victim_plot_blank <- amce_victim_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_leaving_plot_blank <- amce_leaving_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_reconciliation_plot_blank <- amce_reconciliation_plot +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"),
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# MM plot
mm_age_plot_blank <- mm_age_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_joining_plot_blank <- mm_joining_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_atrocity_plot_blank <- mm_atrocity_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_victim_plot_blank <- mm_victim_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_leaving_plot_blank <- mm_leaving_plot +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_reconciliation_plot_blank <- mm_reconciliation_plot +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"), # x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# combine all plots with aligned boxes
choice_amce <- plot_grid(amce_age_plot_blank, 
                         amce_joining_plot_blank, 
                         amce_atrocity_plot_blank, 
                         amce_victim_plot_blank, 
                         amce_leaving_plot_blank, 
                         amce_reconciliation_plot_blank, 
                         ncol=1, nrow=6, 
                         rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
choice_mm <- plot_grid(mm_age_plot_blank, 
                       mm_joining_plot_blank, 
                       mm_atrocity_plot_blank, 
                       mm_victim_plot_blank, 
                       mm_leaving_plot_blank, 
                       mm_reconciliation_plot_blank, 
                       ncol=1, nrow=6, 
                       rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
# safe figure 3 in high resolution
jpeg("Figures/figure3.jpeg", width = 12, height = 12, units = 'in', res = 300)
grid.arrange(choice_amce, choice_mm,
             ncol=2, nrow=1, widths=c(1.95,1))
dev.off()


### 2.1.2. Subset Models (reported in Appendix 2.2 SI -- Model 2-3)
 
### Subset 1
# create subset 1, excl. "0 year" and "Rape"
reintegration.subset.1 <- reintegration.data[ which(reintegration.data$Age!='0 year'
                                                    & reintegration.data$Atrocity!='Rape')]
reintegration.subset.1$Atrocity <- factor(reintegration.subset.1$Atrocity, levels = c("Killings", "Bombings", "Coordinating attacks", "Kidnappings","Rape"))
group_by(reintegration.subset.1, respondent) %>% slice(1)
# model
chosen_model <- chosen ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation
# estimate model using subset dataset 1
chosen_mm_subset.1 <- cj(reintegration.subset.1, chosen_model, id = ~respondent, estimate = "mm")
chosen_mm_subset.1[c("level", "estimate", "std.error", "z", "lower", "upper")]
chosen_amce_subset.1 <- cj(reintegration.subset.1, chosen_model, id = ~respondent, estimate = "amce")
chosen_amce_subset.1[c("level", "estimate", "std.error", "p")]


### Subset 2
# subset 2, excl. "Female" and "Police personnel", "Military personnel", "Government officials"
reintegration.subset.2 <- reintegration.data[ which(reintegration.data$Gender!='Female'
                                                    & reintegration.data$Victim!="Police personnel"
                                                    & reintegration.data$Victim!="Military personnel"
                                                    & reintegration.data$Victim!="Government officials")]
# model
chosen_model_subset.2 <- chosen ~ Age * Joining + Atrocity * Victim + Leaving + Reconciliation
group_by(reintegration.subset.2, respondent) %>% slice(1)
# estimate model using subset dataset 2
chosen_mm_subset.2 <- cj(reintegration.subset.2, chosen_model_subset.2, id = ~respondent, estimate = "mm")
chosen_mm_subset.2[c("level", "estimate", "std.error", "z", "lower", "upper")]
chosen_amce_subset.2 <- cj(reintegration.subset.2, chosen_model_subset.2, id = ~respondent, estimate = "amce")
chosen_amce_subset.2[c("level", "estimate", "std.error", "p")]


### 2.1.3. Full Model (reported in Appendix 2.2 in SI -- Models 4)

chosen_model <- chosen ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation
chosen_model_2 <- chosen ~ Gender + Age + Joining + Atrocity + Victim + Leaving + Reconciliation +
  Age * Joining + Gender * Atrocity + Atrocity * Victim

# descriptive modeling (MMs) and plotting
chosen_mm_full <- cj(reintegration.data, chosen_model, id = ~respondent, estimate = "mm")
chosen_mm_full[c("level", "estimate", "std.error", "z", "lower", "upper")]

# causal modeling (AMCEs) and plotting
chosen_amce_full <- cj(reintegration.data, chosen_model, id = ~respondent, estimate = "amce")
chosen_amce_full[c("level", "estimate", "std.error", "p")]

## The problem with the full model is that some attribute levels are restricted and, hence, we compare dissimilar subsets of profiles along these restricted dimensions. For instance, the quantities of interest of observed preference for soldiers who joined at age 30 is averaged over all possible reasons to join, while the AMCE/MM for child soldiers is only averaged over those who were born within Boko Haram. We therefore calculate the quantities of interest over (1) the levels of the feature of interest only (i.e., the results reported in the main paper), (2) subsets of the design that are conditionally unconstrained, and (3) all features (i.e., the models estimated above) with the explicit caveat that the comparison happens across dissimilar subsets of profiles for the age, gender, atrocity, and victim attributes. Any significant discrepancy will be reported in the main paper.



## 2.2. Secondary Analyses: Implications Mechanisms ----------------------------

### 2.2.1. Rating of Success --------------------------------------------------- 
describe(reintegration.data$rating)

#### Gender -------------
rating_gender <- rating ~ Gender

# 1) descriptive modeling and plotting
rating_mm_gender <- mm(reintegration.data, rating_gender, id = ~respondent)
rating_mm_gender[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_gender_plot_rating <- plot(rating_mm_gender,
                             feature_headers = FALSE, 
                             feature_order = c(),
                             legend_pos = "none",
                             xlim = c(4.46, 6.46),
                             xlab = "Marginal mean",
                             vline = 5.456, vline_color = "black",
                             size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 2) causal modeling and plotting
rating_amce_gender <- amce(reintegration.data, rating_gender, id = ~respondent)
rating_amce_gender[c("level", "estimate", "std.error", "p")]
#jpeg("amce_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_gender_plot_rating <- plot(rating_amce_gender,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(-0.1, 1.5),
                               xlab = "Average marginal component effect",
                               vline = 0.0, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 3) Combine AMCE and MM plot 
grid.arrange(amce_gender_plot_rating, mm_gender_plot_rating, ncol=2)


#### Age -------------
rating_age <- rating ~ Age

# descriptive modeling and plotting
rating_mm_age <- mm(reintegration.data, rating_age, id = ~respondent)
rating_mm_age[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_age_plot_rating <- plot(rating_mm_age,
                          feature_headers = FALSE, 
                          feature_order = c(),
                          legend_pos = "none",
                          xlim = c(4.46, 6.46),
                          xlab = "Marginal mean",
                          vline = 5.456, vline_color = "black",
                          size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
rating_amce_age <- amce(reintegration.data, rating_age, id = ~respondent)
rating_amce_age[c("level", "estimate", "std.error", "p")]
#jpeg("amce_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_age_plot_rating <- plot(rating_amce_age,
                            feature_headers = FALSE, 
                            feature_order = c(),
                            legend_pos = "none",
                            xlim = c(-0.1, 1.5),
                            xlab = "Average marginal component effect",
                            vline = 0.0, vline_color = "black",
                            size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_age_plot_rating, mm_age_plot_rating, ncol=2)


#### Reason for joining -------------
rating_joining <- rating ~ Joining

# descriptive modeling and plotting
rating_mm_joining <- mm(reintegration.data, rating_joining, id = ~respondent)
rating_mm_joining[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_joining_plot_rating <- plot(rating_mm_joining,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(4.46, 6.46),
                              xlab = "Marginal mean",
                              vline = 5.456, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
rating_amce_joining <- amce(reintegration.data, rating_joining, id = ~respondent)
head(rating_amce_joining[c("level", "estimate", "std.error", "p")])
#jpeg("amce_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_joining_plot_rating <- plot(rating_amce_joining,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(-0.1, 1.5),
                                xlab = "Average marginal component effect",
                                vline = 0.0, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_joining_plot_rating, mm_joining_plot_rating, ncol=2)


#### Atrocity -------------
rating_atrocity <- rating ~ Atrocity

# descriptive modeling and plotting
rating_mm_atrocity <- mm(reintegration.data, rating_atrocity, id = ~respondent)
rating_mm_atrocity[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_atrocity_plot_rating <- plot(rating_mm_atrocity,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(4.46, 6.46),
                               xlab = "Marginal mean",
                               vline = 5.456, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
rating_amce_atrocity <- amce(reintegration.data, rating_atrocity, id = ~respondent)
rating_amce_atrocity[c("level", "estimate", "std.error", "p")]
#jpeg("amce_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_atrocity_plot_rating <- plot(rating_amce_atrocity,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(-0.1, 1.5),
                                 xlab = "Average marginal component effect",
                                 vline = 0.0, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_atrocity_plot_rating, mm_atrocity_plot_rating, ncol=2)


#### Victim/target -------------
rating_victim <- rating ~ Victim

# descriptive modeling and plotting
rating_mm_victim <- mm(reintegration.data, rating_victim, id = ~respondent)
rating_mm_victim[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_victim_plot_rating <- plot(rating_mm_victim,
                             feature_headers = FALSE, 
                             feature_order = c(),
                             legend_pos = "none",
                             xlim = c(4.46, 6.46),
                             xlab = "Marginal mean",
                             vline = 5.456, vline_color = "black",
                             size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
rating_amce_victim <- amce(reintegration.data, rating_victim, id = ~respondent)
rating_amce_victim[c("level", "estimate", "std.error", "p")]
#jpeg("amce_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_victim_plot_rating <- plot(rating_amce_victim,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(-0.1, 1.5),
                               xlab = "Average marginal component effect",
                               vline = 0.0, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_victim_plot_rating, mm_victim_plot_rating, ncol=2)


#### Reason for leaving -------------
rating_leaving <- rating ~ Leaving

# descriptive modeling and plotting
rating_mm_leaving <- mm(reintegration.data, rating_leaving, id = ~respondent)
rating_mm_leaving[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_leaving_plot_rating <- plot(rating_mm_leaving,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(4.46, 6.46),
                              vline = 5.456, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
rating_amce_leaving <- amce(reintegration.data, rating_leaving, id = ~respondent)
rating_amce_leaving[c("level", "estimate", "std.error", "p")]
#jpeg("amce_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_leaving_plot_rating <- plot(rating_amce_leaving,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(-0.1, 1.5),
                                xlab = "Average marginal component effect",
                                vline = 0.0, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_leaving_plot_rating, mm_leaving_plot_rating, ncol=2)


#### Conciliatory gestures -------------
rating_reconciliation <- rating ~ Reconciliation

# descriptive modeling and plotting
rating_mm_reconciliation <- mm(reintegration.data, rating_reconciliation, id = ~respondent)
rating_mm_reconciliation[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_reconciliation_plot_rating <- plot(rating_mm_reconciliation,
                                     feature_headers = FALSE, 
                                     feature_order = c(),
                                     legend_pos = "none",
                                     xlim = c(4.46, 6.46),
                                     xlab = "Marginal mean",
                                     vline = 5.456, vline_color = "black",
                                     size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
rating_amce_reconciliation <- amce(reintegration.data, rating_reconciliation, id = ~respondent)
rating_amce_reconciliation[c("level", "estimate", "std.error", "p")]
#jpeg("amce_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_reconciliation_plot_rating <- plot(rating_amce_reconciliation,
                                       feature_headers = FALSE, 
                                       feature_order = c(),
                                       legend_pos = "none",
                                       xlim = c(-0.1, 1.5),
                                       xlab = "Average marginal component effect",
                                       vline = 0.0, vline_color = "black",
                                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_reconciliation_plot_rating, mm_reconciliation_plot_rating, ncol=2)


####################### FIGURE A4 #####################
## AMCE plot
amce_age_plot_rating_blank <- amce_age_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_joining_plot_rating_blank <- amce_joining_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_atrocity_plot_rating_blank <- amce_atrocity_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_victim_plot_rating_blank <- amce_victim_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_leaving_plot_rating_blank <- amce_leaving_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_reconciliation_plot_rating_blank <- amce_reconciliation_plot_rating +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"),
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# MM plot
mm_age_plot_rating_blank <- mm_age_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_joining_plot_rating_blank <- mm_joining_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_atrocity_plot_rating_blank <- mm_atrocity_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_victim_plot_rating_blank <- mm_victim_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_leaving_plot_rating_blank <- mm_leaving_plot_rating +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_reconciliation_plot_rating_blank <- mm_reconciliation_plot_rating +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"), # x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# combine all plots with aligned boxes
rating_amce <- plot_grid(amce_age_plot_rating_blank, 
                        amce_joining_plot_rating_blank, 
                        amce_atrocity_plot_rating_blank, 
                        amce_victim_plot_rating_blank, 
                        amce_leaving_plot_rating_blank, 
                        amce_reconciliation_plot_rating_blank, 
                        ncol=1, nrow=6, 
                        rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
rating_mm <- plot_grid(mm_age_plot_rating_blank, 
                      mm_joining_plot_rating_blank, 
                      mm_atrocity_plot_rating_blank, 
                      mm_victim_plot_rating_blank, 
                      mm_leaving_plot_rating_blank, 
                      mm_reconciliation_plot_rating_blank, 
                      ncol=1, nrow=6, 
                      rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
# safe figure A4 (Appendix) in high resolution
jpeg("Figures/SI_figure4.jpeg", width = 12, height = 12, units = 'in', res = 300)
grid.arrange(rating_amce, rating_mm,
             ncol=2, nrow=1, widths=c(1.95,1))
dev.off()


### 2.2.2. Amnesty ------------------------------------------------------------- 
summary(as.factor(reintegration.data$amnesty))
4092 / (4092 + 7812)

#### Gender -------------
amnesty_gender <- amnesty ~ Gender

# 1) descriptive modeling and plotting
amnesty_mm_gender <- mm(reintegration.data, amnesty_gender, id = ~respondent)
amnesty_mm_gender[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_gender_plot_amnesty <- plot(amnesty_mm_gender,
                       feature_headers = FALSE, 
                       feature_order = c(),
                       legend_pos = "none",
                       xlim = c(0.20375, 0.48375),
                       xlab = "Marginal mean",
                       vline = 0.34375, vline_color = "black",
                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 2) causal modeling and plotting
amnesty_amce_gender <- amce(reintegration.data, amnesty_gender, id = ~respondent)
amnesty_amce_gender[c("level", "estimate", "std.error", "p")]
#jpeg("amce_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_gender_plot_amnesty <- plot(amnesty_amce_gender,
                         feature_headers = FALSE, 
                         feature_order = c(),
                         legend_pos = "none",
                         xlim = c(-0.05,0.25),
                         xlab = "Average marginal component effect",
                         vline = 0.0, vline_color = "black",
                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 3) Combine AMCE and MM plot 
grid.arrange(amce_gender_plot_amnesty, mm_gender_plot_amnesty, ncol=2)


#### Age -------------
amnesty_age <- amnesty ~ Age

# descriptive modeling and plotting
amnesty_mm_age <- mm(reintegration.data, amnesty_age, id = ~respondent)
amnesty_mm_age[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_age_plot_amnesty <- plot(amnesty_mm_age,
                    feature_headers = FALSE, 
                    feature_order = c(),
                    legend_pos = "none",
                    xlim = c(0.20375, 0.48375),
                    xlab = "Marginal mean",
                    vline = 0.34375, vline_color = "black",
                    size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
amnesty_amce_age <- amce(reintegration.data, amnesty_age, id = ~respondent)
amnesty_amce_age[c("level", "estimate", "std.error", "p")]
#jpeg("amce_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_age_plot_amnesty <- plot(amnesty_amce_age,
                      feature_headers = FALSE, 
                      feature_order = c(),
                      legend_pos = "none",
                      xlim = c(-0.05,0.25),
                      xlab = "Average marginal component effect",
                      vline = 0.0, vline_color = "black",
                      size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_age_plot_amnesty, mm_age_plot_amnesty, ncol=2)


#### Reason for joining -------------
amnesty_joining <- amnesty ~ Joining

# descriptive modeling and plotting
amnesty_mm_joining <- mm(reintegration.data, amnesty_joining, id = ~respondent)
amnesty_mm_joining[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_joining_plot_amnesty <- plot(amnesty_mm_joining,
                        feature_headers = FALSE, 
                        feature_order = c(),
                        legend_pos = "none",
                        xlim = c(0.20375, 0.48375),
                        xlab = "Marginal mean",
                        vline = 0.34375, vline_color = "black",
                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
amnesty_amce_joining <- amce(reintegration.data, amnesty_joining, id = ~respondent)
head(amnesty_amce_joining[c("level", "estimate", "std.error", "p")])
#jpeg("amce_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_joining_plot_amnesty <- plot(amnesty_amce_joining,
                          feature_headers = FALSE, 
                          feature_order = c(),
                          legend_pos = "none",
                          xlim = c(-0.05,0.25),
                          xlab = "Average marginal component effect",
                          vline = 0.0, vline_color = "black",
                          size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_joining_plot_amnesty, mm_joining_plot_amnesty, ncol=2)


#### Atrocity -------------
amnesty_atrocity <- amnesty ~ Atrocity

# descriptive modeling and plotting
amnesty_mm_atrocity <- mm(reintegration.data, amnesty_atrocity, id = ~respondent)
amnesty_mm_atrocity[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_atrocity_plot_amnesty <- plot(amnesty_mm_atrocity,
                         feature_headers = FALSE, 
                         feature_order = c(),
                         legend_pos = "none",
                         xlim = c(0.20375, 0.48375),
                         xlab = "Marginal mean",
                         vline = 0.34375, vline_color = "black",
                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
amnesty_amce_atrocity <- amce(reintegration.data, amnesty_atrocity, id = ~respondent)
amnesty_amce_atrocity[c("level", "estimate", "std.error", "p")]
#jpeg("amce_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_atrocity_plot_amnesty <- plot(amnesty_amce_atrocity,
                           feature_headers = FALSE, 
                           feature_order = c(),
                           legend_pos = "none",
                           xlim = c(-0.05,0.25),
                           xlab = "Average marginal component effect",
                           vline = 0.0, vline_color = "black",
                           size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_atrocity_plot_amnesty, mm_atrocity_plot_amnesty, ncol=2)


#### Victim/target -------------
amnesty_victim <- amnesty ~ Victim

# descriptive modeling and plotting
amnesty_mm_victim <- mm(reintegration.data, amnesty_victim, id = ~respondent)
amnesty_mm_victim[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_victim_plot_amnesty <- plot(amnesty_mm_victim,
                       feature_headers = FALSE, 
                       feature_order = c(),
                       legend_pos = "none",
                       xlim = c(0.20375, 0.48375),
                       xlab = "Marginal mean",
                       vline = 0.34375, vline_color = "black",
                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
amnesty_amce_victim <- amce(reintegration.data, amnesty_victim, id = ~respondent)
amnesty_amce_victim[c("level", "estimate", "std.error", "p")]
#jpeg("amce_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_victim_plot_amnesty <- plot(amnesty_amce_victim,
                         feature_headers = FALSE, 
                         feature_order = c(),
                         legend_pos = "none",
                         xlim = c(-0.05,0.25),
                         xlab = "Average marginal component effect",
                         vline = 0.0, vline_color = "black",
                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_victim_plot_amnesty, mm_victim_plot_amnesty, ncol=2)


#### Reason for leaving -------------
amnesty_leaving <- amnesty ~ Leaving

# descriptive modeling and plotting
amnesty_mm_leaving <- mm(reintegration.data, amnesty_leaving, id = ~respondent)
amnesty_mm_leaving[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_leaving_plot_amnesty <- plot(amnesty_mm_leaving,
                        feature_headers = FALSE, 
                        feature_order = c(),
                        legend_pos = "none",
                        xlim = c(0.20375, 0.48375),
                        vline = 0.34375, vline_color = "black",
                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
amnesty_amce_leaving <- amce(reintegration.data, amnesty_leaving, id = ~respondent)
amnesty_amce_leaving[c("level", "estimate", "std.error", "p")]
#jpeg("amce_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_leaving_plot_amnesty <- plot(amnesty_amce_leaving,
                          feature_headers = FALSE, 
                          feature_order = c(),
                          legend_pos = "none",
                          xlim = c(-0.05,0.25),
                          xlab = "Average marginal component effect",
                          vline = 0.0, vline_color = "black",
                          size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_leaving_plot_amnesty, mm_leaving_plot_amnesty, ncol=2)


#### Conciliatory gestures -------------
amnesty_reconciliation <- amnesty ~ Reconciliation

# descriptive modeling and plotting
amnesty_mm_reconciliation <- mm(reintegration.data, amnesty_reconciliation, id = ~respondent)
amnesty_mm_reconciliation[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_reconciliation_plot_amnesty <- plot(amnesty_mm_reconciliation,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.20375, 0.48375),
                               xlab = "Marginal mean",
                               vline = 0.34375, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
amnesty_amce_reconciliation <- amce(reintegration.data, amnesty_reconciliation, id = ~respondent)
amnesty_amce_reconciliation[c("level", "estimate", "std.error", "p")]
#jpeg("amce_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_reconciliation_plot_amnesty <- plot(amnesty_amce_reconciliation,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(-0.05,0.25),
                                 xlab = "Average marginal component effect",
                                 vline = 0.0, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_reconciliation_plot_amnesty, mm_reconciliation_plot_amnesty, ncol=2)


####################### FIGURE A5 #####################
## AMCE plot
amce_age_plot_amnesty_blank <- amce_age_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_joining_plot_amnesty_blank <- amce_joining_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_atrocity_plot_amnesty_blank <- amce_atrocity_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_victim_plot_amnesty_blank <- amce_victim_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_leaving_plot_amnesty_blank <- amce_leaving_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_reconciliation_plot_amnesty_blank <- amce_reconciliation_plot_amnesty +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"),
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# MM plot
mm_age_plot_amnesty_blank <- mm_age_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_joining_plot_amnesty_blank <- mm_joining_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_atrocity_plot_amnesty_blank <- mm_atrocity_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_victim_plot_amnesty_blank <- mm_victim_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_leaving_plot_amnesty_blank <- mm_leaving_plot_amnesty +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_reconciliation_plot_amnesty_blank <- mm_reconciliation_plot_amnesty +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"), # x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# combine all plots with aligned boxes
amnesty_amce <- plot_grid(amce_age_plot_amnesty_blank, 
                         amce_joining_plot_amnesty_blank, 
                         amce_atrocity_plot_amnesty_blank, 
                         amce_victim_plot_amnesty_blank, 
                         amce_leaving_plot_amnesty_blank, 
                         amce_reconciliation_plot_amnesty_blank, 
                         ncol=1, nrow=6, 
                         rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
amnesty_mm <- plot_grid(mm_age_plot_amnesty_blank, 
                       mm_joining_plot_amnesty_blank, 
                       mm_atrocity_plot_amnesty_blank, 
                       mm_victim_plot_amnesty_blank, 
                       mm_leaving_plot_amnesty_blank, 
                       mm_reconciliation_plot_amnesty_blank, 
                       ncol=1, nrow=6, 
                       rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
# safe figure A5 (Appendix) in high resolution
jpeg("Figures/SI_figure5.jpeg", width = 12, height = 12, units = 'in', res = 300)
grid.arrange(amnesty_amce, amnesty_mm,
             ncol=2, nrow=1, widths=c(1.95,1))
dev.off()


### 2.2.3. Death Penalty ------------------------------------------------------- 
summary(as.factor(reintegration.data$death))
2369 / (9535 + 2369)


#### Gender -------------
death_gender <- death ~ Gender

# 1) descriptive modeling and plotting
death_mm_gender <- mm(reintegration.data, death_gender, id = ~respondent)
death_mm_gender[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_gender_plot_death <- plot(death_mm_gender,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.0990087, 0.2990087),
                               xlab = "Marginal mean",
                               vline = 0.1990087, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 2) causal modeling and plotting
death_amce_gender <- amce(reintegration.data, death_gender, id = ~respondent)
death_amce_gender[c("level", "estimate", "std.error", "p")]
#jpeg("amce_gender.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_gender_plot_death <- plot(death_amce_gender,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(-0.15,0.05),
                                 xlab = "Average marginal component effect",
                                 vline = 0.0, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# 3) Combine AMCE and MM plot 
grid.arrange(amce_gender_plot_death, mm_gender_plot_death, ncol=2)


#### Age -------------
death_age <- death ~ Age

# descriptive modeling and plotting
death_mm_age <- mm(reintegration.data, death_age, id = ~respondent)
death_mm_age[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_age_plot_death <- plot(death_mm_age,
                            feature_headers = FALSE, 
                            feature_order = c(),
                            legend_pos = "none",
                            xlim = c(0.0990087, 0.2990087),
                            xlab = "Marginal mean",
                            vline = 0.1990087, vline_color = "black",
                            size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
death_amce_age <- amce(reintegration.data, death_age, id = ~respondent)
death_amce_age[c("level", "estimate", "std.error", "p")]
#jpeg("amce_age.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_age_plot_death <- plot(death_amce_age,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(-0.15,0.05),
                              xlab = "Average marginal component effect",
                              vline = 0.0, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_age_plot_death, mm_age_plot_death, ncol=2)


#### Reason for joining -------------
death_joining <- death ~ Joining

# descriptive modeling and plotting
death_mm_joining <- mm(reintegration.data, death_joining, id = ~respondent)
death_mm_joining[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_joining_plot_death <- plot(death_mm_joining,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(0.0990087, 0.2990087),
                                xlab = "Marginal mean",
                                vline = 0.1990087, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
death_amce_joining <- amce(reintegration.data, death_joining, id = ~respondent)
head(death_amce_joining[c("level", "estimate", "std.error", "p")])
#jpeg("amce_joining.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_joining_plot_death <- plot(death_amce_joining,
                                  feature_headers = FALSE, 
                                  feature_order = c(),
                                  legend_pos = "none",
                                  xlim = c(-0.15,0.05),
                                  xlab = "Average marginal component effect",
                                  vline = 0.0, vline_color = "black",
                                  size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_joining_plot_death, mm_joining_plot_death, ncol=2)


#### Atrocity -------------
death_atrocity <- death ~ Atrocity

# descriptive modeling and plotting
death_mm_atrocity <- mm(reintegration.data, death_atrocity, id = ~respondent)
death_mm_atrocity[c("level", "estimate", "std.error", "z", "lower", "upper")]
#jpeg("mm_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_atrocity_plot_death <- plot(death_mm_atrocity,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(0.0990087, 0.2990087),
                                 xlab = "Marginal mean",
                                 vline = 0.1990087, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
death_amce_atrocity <- amce(reintegration.data, death_atrocity, id = ~respondent)
death_amce_atrocity[c("level", "estimate", "std.error", "p")]
#jpeg("amce_atrocity.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_atrocity_plot_death <- plot(death_amce_atrocity,
                                   feature_headers = FALSE, 
                                   feature_order = c(),
                                   legend_pos = "none",
                                   xlim = c(-0.15,0.05),
                                   xlab = "Average marginal component effect",
                                   vline = 0.0, vline_color = "black",
                                   size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_atrocity_plot_death, mm_atrocity_plot_death, ncol=2)


#### Victim/target -------------
death_victim <- death ~ Victim

# descriptive modeling and plotting
death_mm_victim <- mm(reintegration.data, death_victim, id = ~respondent)
death_mm_victim[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_victim_plot_death <- plot(death_mm_victim,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.0990087, 0.2990087),
                               xlab = "Marginal mean",
                               vline = 0.1990087, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
death_amce_victim <- amce(reintegration.data, death_victim, id = ~respondent)
death_amce_victim[c("level", "estimate", "std.error", "p")]
#jpeg("amce_victim.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_victim_plot_death <- plot(death_amce_victim,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(-0.15,0.05),
                                 xlab = "Average marginal component effect",
                                 vline = 0.0, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_victim_plot_death, mm_victim_plot_death, ncol=2)


#### Reason for leaving -------------
death_leaving <- death ~ Leaving

# descriptive modeling and plotting
death_mm_leaving <- mm(reintegration.data, death_leaving, id = ~respondent)
death_mm_leaving[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_leaving_plot_death <- plot(death_mm_leaving,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(0.0990087, 0.2990087),
                                vline = 0.1990087, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
death_amce_leaving <- amce(reintegration.data, death_leaving, id = ~respondent)
death_amce_leaving[c("level", "estimate", "std.error", "p")]
#jpeg("amce_leaving.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_leaving_plot_death <- plot(death_amce_leaving,
                                  feature_headers = FALSE, 
                                  feature_order = c(),
                                  legend_pos = "none",
                                  xlim = c(-0.15,0.05),
                                  xlab = "Average marginal component effect",
                                  vline = 0.0, vline_color = "black",
                                  size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_leaving_plot_death, mm_leaving_plot_death, ncol=2)


#### Conciliatory gestures -------------
death_reconciliation <- death ~ Reconciliation

# descriptive modeling and plotting
death_mm_reconciliation <- mm(reintegration.data, death_reconciliation, id = ~respondent)
death_mm_reconciliation[c("level", "estimate", "std.error", "lower", "upper")]
#jpeg("mm_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
mm_reconciliation_plot_death <- plot(death_mm_reconciliation,
                                       feature_headers = FALSE, 
                                       feature_order = c(),
                                       legend_pos = "none",
                                       xlim = c(0.0990087, 0.2990087),
                                       xlab = "Marginal mean",
                                       vline = 0.1990087, vline_color = "black",
                                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# causal modeling and plotting
death_amce_reconciliation <- amce(reintegration.data, death_reconciliation, id = ~respondent)
death_amce_reconciliation[c("level", "estimate", "std.error", "p")]
#jpeg("amce_reconciliation.jpeg", width = 5, height = 3.5, units = 'in', res = 300)
amce_reconciliation_plot_death <- plot(death_amce_reconciliation,
                                         feature_headers = FALSE, 
                                         feature_order = c(),
                                         legend_pos = "none",
                                         xlim = c(-0.15,0.05),
                                         xlab = "Average marginal component effect",
                                         vline = 0.0, vline_color = "black",
                                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") +
  scale_color_manual(values = mycols) #change colors to black for publication
#dev.off()

# combine AMCE and MM plot
grid.arrange(amce_reconciliation_plot_death, mm_reconciliation_plot_death, ncol=2)


####################### FIGURE A6 #####################
## AMCE plot
amce_age_plot_death_blank <- amce_age_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_joining_plot_death_blank <- amce_joining_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_atrocity_plot_death_blank <- amce_atrocity_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_victim_plot_death_blank <- amce_victim_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_leaving_plot_death_blank <- amce_leaving_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
amce_reconciliation_plot_death_blank <- amce_reconciliation_plot_death +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"),
        axis.text.y =  element_text(size = 16, colour = "black"), # text in black instead of grey
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# MM plot
mm_age_plot_death_blank <- mm_age_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_joining_plot_death_blank <- mm_joining_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_atrocity_plot_death_blank <- mm_atrocity_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_victim_plot_death_blank <- mm_victim_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_leaving_plot_death_blank <- mm_leaving_plot_death +
  theme(axis.title.x = element_blank(), # remove title x-axis
        axis.text.x = element_blank(), axis.ticks.x=element_blank(), # remove x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
mm_reconciliation_plot_death_blank <- mm_reconciliation_plot_death +
  theme(axis.title.x = element_text(size = 16, colour = "black"), # title x-axis
        axis.text.x = element_text(size = 16, colour = "black"), # x-axis
        axis.text.y = element_blank(), axis.ticks.y=element_blank(), # remove y-axis
        strip.text.y = element_text(size = 16, colour = "black"), # text in black instead of grey
        panel.border = element_rect(fill=NA, colour = "black")) # black borders as well.
# combine all plots with aligned boxes
death_amce <- plot_grid(amce_age_plot_death_blank, 
                          amce_joining_plot_death_blank, 
                          amce_atrocity_plot_death_blank, 
                          amce_victim_plot_death_blank, 
                          amce_leaving_plot_death_blank, 
                          amce_reconciliation_plot_death_blank, 
                          ncol=1, nrow=6, 
                          rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
death_mm <- plot_grid(mm_age_plot_death_blank, 
                        mm_joining_plot_death_blank, 
                        mm_atrocity_plot_death_blank, 
                        mm_victim_plot_death_blank, 
                        mm_leaving_plot_death_blank, 
                        mm_reconciliation_plot_death_blank, 
                        ncol=1, nrow=6, 
                        rel_heights=c(1.1,1,1,1.1,1,1.3), align = "v")
# safe figure A6 (Appendix) in high resolution
jpeg("Figures/SI_figure6.jpeg", width = 12, height = 12, units = 'in', res = 300)
grid.arrange(death_amce, death_mm,
             ncol=2, nrow=1, widths=c(1.95,1))
dev.off()


####################### TABLE III #####################
# Association between success ratings and preferred punishments 
# categorize ratings
summary(as.factor(reintegration.data$rating))
summary(reintegration.data$rating)
reintegration.data$ratinggroup <- quantcut(reintegration.data$rating, q=4)
summary(as.factor(reintegration.data$ratinggroup))
# association rating and death penalty
xdeath <- xtabs(~death+ratinggroup, data=reintegration.data)
summary(xdeath) 
ftable(xdeath) 
prop.table(xdeath, 2)# column percentages
# association rating and amnesty
xamnesty <- xtabs(~amnesty+ratinggroup, data=reintegration.data)
summary(xamnesty) 
ftable(xamnesty) 
prop.table(xamnesty, 2)# column percentages
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



## 2.3. Secondary Analyses: Moderation -----------------------------------------

# important information.
# first, we only estimate MMs as AMCEs can be misleading because of their sensitivity to the reference category (Leeper et al. 2019)
# second, f-tests are used to test significance of conditional effect. The F-test compares the two model with and without the two-way interactions and, hence, provides a formal test for whether preferences vary across levels of BY. This is, in essence, a test of whether all such interaction coefficients are distinguishable from zero. (Because the test depends on overall model fit, not the coefficient variances, clustering is irrelevant.)

### 2.3.1. By Religion --------------------------------------------------- 

# Delete respondents without/with another religion
summary(reintegration.data$religion)
reintegration_religion.data <- reintegration.data[ reintegration.data$religion != "Other/No", , drop=FALSE]
reintegration_religion.data$religion <- factor(reintegration_religion.data$religion)
summary(reintegration_religion.data$religion)

# All features
cj_anova(reintegration_religion.data, chosen_model, by = ~ religion) 

#### Gender -------------
# anova
cj_anova(reintegration_religion.data, gender, by = ~ religion)
# estimation
gender_by_religion <- cj(reintegration_religion.data, gender, id = ~respondent, estimate = "mm",
                         by = ~ religion)
gender_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
gender_by_religion_plot <- plot(gender_by_religion,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(0.3,0.7),
                              vline = 0.5, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("religion", values = c("Black", "Gray"))


#### Age -------------
# anova
cj_anova(reintegration.data, age, by = ~ religion)
# estimation
age_by_religion <- cj(reintegration_religion.data, age, id = ~ respondent, estimate = "mm",
                      by = ~ religion)
age_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
age_by_religion_plot <- plot(age_by_religion,
                           feature_headers = FALSE, 
                           feature_order = c(),
                           legend_pos = "none",
                           xlim = c(0.3,0.7),
                           vline = 0.5, vline_color = "black",
                           size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("religion", values = c("Black", "Gray"))


#### Reason for joining -------------
# anova
cj_anova(reintegration_religion.data, joining, by = ~ religion)
# estimation
joining_by_religion <- cj(reintegration_religion.data, joining, id = ~respondent, estimate = "mm",
                          by = ~ religion)
joining_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
joining_by_religion_plot <- plot(joining_by_religion,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.3,0.7),
                               vline = 0.5, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("religion", values = c("Black", "Gray"))


#### Atrocity -------------
# anova
cj_anova(reintegration_religion.data, atrocity, by = ~ religion)
# estimation
atrocity_by_religion <- cj(reintegration_religion.data, atrocity, id = ~respondent, estimate = "mm", 
                           by = ~ religion)
atrocity_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
atrocity_by_religion_plot <- plot(atrocity_by_religion,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(0.3,0.7),
                                vline = 0.5, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("religion", values = c("Black", "Gray"))


#### Victim/target -------------
# anova
cj_anova(reintegration_religion.data, victim, by = ~ religion)
# estimation
victim_by_religion <- cj(reintegration_religion.data, victim, id = ~respondent, estimate = "mm",
                         by = ~ religion)
victim_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
victim_by_religion_plot <- plot(victim_by_religion,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(0.3,0.7),
                              vline = 0.5, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("religion", values = c("Black", "Gray"))


#### Reason for leaving -------------
# anova
cj_anova(reintegration_religion.data, leaving, by = ~ religion)
# estimation
leaving_by_religion <- cj(reintegration_religion.data, leaving, id = ~respondent, estimate = "mm",
                          by = ~ religion)
leaving_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
leaving_by_religion_plot <- plot(leaving_by_religion,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.3,0.7),
                               vline = 0.5, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("religion", values = c("Black", "Gray"))


#### Conciliatory gestures -------------
# anova
cj_anova(reintegration_religion.data, reconciliation, by = ~ religion)
# estimation
reconciliation_by_religion <- cj(reintegration_religion.data, reconciliation, id = ~respondent, estimate = "mm", by = ~ religion)
reconciliation_by_religion[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
reconciliation_by_religion_plot <- plot(reconciliation_by_religion,
                                      feature_headers = FALSE, 
                                      feature_order = c(),
                                      legend_pos = "bottom",
                                      legend_title = "By religion",
                                      xlim = c(0.3,0.7),
                                      xlab = "Conditional marginal means",
                                      vline = 0.5, vline_color = "black",
                                      size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual(values = c("Black", "Gray"))



### 2.3.2. By Region --------------------------------------------------- 

# Delete respondents without/with another region
summary(reintegration.data$geopolitical_zone)
reintegration.data$region <- recode(wide.data$geopolitical_zone,
                                    NC = "North", NE = "North", NW = "North", 
                                    SE = "South", SS = "South", SW= "South") 
reintegration.data$region <- na_if(reintegration.data$region, "Not Nigeria") 
reintegration.data$region <- factor(reintegration.data$region,
                                    levels = c("South", "North"))
summary(reintegration.data$region)
reintegration_region.data <- na.omit(reintegration.data, cols=c("region"))
summary(reintegration_region.data$region)


# All features
cj_anova(reintegration_region.data, chosen_model, by = ~ region) 


#### Gender -------------
# anova
cj_anova(reintegration_region.data, gender, by = ~ region)
# estimation
gender_by_region <- cj(reintegration_region.data, gender, id = ~respondent, estimate = "mm", by = ~ region)
gender_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
gender_by_region_plot <- plot(gender_by_region,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(0.3,0.7),
                                vline = 0.5, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("region", values = c("Black", "Gray"))


#### Age -------------
# anova
cj_anova(reintegration_region.data, age, by = ~ region)
# estimation
age_by_region <- cj(reintegration_region.data, age, id = ~ respondent, estimate = "mm", by = ~ region)
age_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
age_by_region_plot <- plot(age_by_region,
                             feature_headers = FALSE, 
                             feature_order = c(),
                             legend_pos = "none",
                             xlim = c(0.3,0.7),
                             vline = 0.5, vline_color = "black",
                             size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("region", values = c("Black", "Gray"))


#### Reason for joining -------------
# anova
cj_anova(reintegration_region.data, joining, by = ~ region)
# estimation
joining_by_region <- cj(reintegration_region.data, joining, id = ~respondent, estimate = "mm", by = ~ region)
joining_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
joining_by_region_plot <- plot(joining_by_region,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(0.3,0.7),
                                 vline = 0.5, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("region", values = c("Black", "Gray"))


#### Atrocity -------------
# anova
cj_anova(reintegration_region.data, atrocity, by = ~ region)
# estimation
atrocity_by_region <- cj(reintegration_region.data, atrocity, id = ~respondent, estimate = "mm", by = ~ region)
atrocity_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
atrocity_by_region_plot <- plot(atrocity_by_region,
                                  feature_headers = FALSE, 
                                  feature_order = c(),
                                  legend_pos = "none",
                                  xlim = c(0.3,0.7),
                                  vline = 0.5, vline_color = "black",
                                  size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("region", values = c("Black", "Gray"))


#### Victim/target -------------
# anova
cj_anova(reintegration_region.data, victim, by = ~ region)
# estimation
victim_by_region <- cj(reintegration_region.data, victim, id = ~respondent, estimate = "mm", by = ~ region)
victim_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
victim_by_region_plot <- plot(victim_by_region,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(0.3,0.7),
                                vline = 0.5, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("region", values = c("Black", "Gray"))


#### Reason for leaving -------------
# anova
cj_anova(reintegration_region.data, leaving, by = ~ region)
# estimation
leaving_by_region <- cj(reintegration_region.data, leaving, id = ~respondent, estimate = "mm", by = ~ region)
leaving_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
leaving_by_region_plot <- plot(leaving_by_region,
                                 feature_headers = FALSE, 
                                 feature_order = c(),
                                 legend_pos = "none",
                                 xlim = c(0.3,0.7),
                                 vline = 0.5, vline_color = "black",
                                 size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("region", values = c("Black", "Gray"))


#### Conciliatory gestures -------------
# anova
cj_anova(reintegration_region.data, reconciliation, by = ~ region)
# estimation
reconciliation_by_region <- cj(reintegration_region.data, reconciliation, id = ~respondent, estimate = "mm", by = ~ region)
reconciliation_by_region[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
reconciliation_by_region_plot <- plot(reconciliation_by_region,
                                        feature_headers = FALSE, 
                                        feature_order = c(),
                                        legend_pos = "bottom",
                                        legend_title = "By region",
                                        xlim = c(0.3,0.7),
                                        xlab = "Conditional marginal means",
                                        vline = 0.5, vline_color = "black",
                                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual(values = c("Black", "Gray"))



#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
####################### FIGURE 4 ######################
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
## By Religion
mm_by_religion <- plot_grid(age_by_religion_plot +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          joining_by_religion_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          atrocity_by_religion_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          victim_by_religion_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          leaving_by_religion_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          reconciliation_by_religion_plot +
                            theme(axis.text.x = element_text(size = 16, colour = "black"),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  legend.title = element_text(size = 16, colour = "black"),
                                  legend.text = element_text(colour="black", size = 16),
                                  axis.title = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")), 
                          ncol=1, nrow=6, rel_heights=c(1.2,1,1,1.2,1,1.7), align = "v")
# By region
mm_by_region <- plot_grid(age_by_region_plot +
                            theme(axis.title.x = element_blank(),
                                  axis.text.y = element_blank(), axis.ticks.y=element_blank(), 
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          joining_by_region_plot +
                            theme(axis.title.x = element_blank(),
                                  axis.text.y = element_blank(), axis.ticks.y=element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          atrocity_by_region_plot +
                            theme(axis.title.x = element_blank(),
                                  axis.text.y = element_blank(), axis.ticks.y=element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          victim_by_region_plot +
                            theme(axis.title.x = element_blank(),axis.text.y = element_blank(),
                                  axis.ticks.y=element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          leaving_by_region_plot +
                            theme(axis.title.x = element_blank(),
                                  axis.text.y = element_blank(), axis.ticks.y=element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          reconciliation_by_region_plot +
                            theme(axis.title = element_text(size = 16, colour = "black"),
                                  axis.text.x = element_text(size = 16, colour = "black"),
                                  axis.text.y.left = element_blank(), axis.ticks.y=element_blank(),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  legend.title = element_text(size = 16, colour = "black"),
                                  legend.text = element_text(colour="black", size = 16),
                                  panel.border = element_rect(fill=NA, colour = "black")), 
                          ncol=1, nrow=6, rel_heights=c(1.2,1,1,1.2,1,1.7), align = "v")
# Combine plots and save in high resolution
jpeg("Figures/figure4.jpeg", width =12, height = 12, units = 'in', res = 300)
grid.arrange(mm_by_religion, mm_by_region,
             ncol=2,
             widths=c(1.95,1))
dev.off()
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


### 2.3.3. By Perceived Victimization ------------------------------------------ 
cj_anova(reintegration.data, chosen_model, by = ~ victimization_1) # all features

#### Gender -------------
# anova
cj_anova(reintegration.data, gender, by = ~ victimization_1)
# estimation
gender_by_victimization_1 <- cj(reintegration.data, gender, id = ~respondent, estimate = "mm", by = ~ victimization_1)
gender_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
gender_by_victimization_1_plot <- plot(gender_by_victimization_1,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(0.3,0.7),
                              vline = 0.5, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))

#### Age -------------
# anova
cj_anova(reintegration.data, age, by = ~ victimization_1)
# estimation
age_by_victimization_1 <- cj(reintegration.data, age, id = ~respondent, estimate = "mm", by = ~ victimization_1)
age_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
age_by_victimization_1_plot <- plot(age_by_victimization_1,
                           feature_headers = FALSE, 
                           feature_order = c(),
                           legend_pos = "none",
                           xlim = c(0.3,0.7),
                           vline = 0.5, vline_color = "black",
                           size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))

#### Reason for joining -------------
# anova
cj_anova(reintegration.data, joining, by = ~ victimization_1)
# estimation
joining_by_victimization_1 <- cj(reintegration.data, joining, id = ~respondent, estimate = "mm", by = ~ victimization_1)
joining_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
joining_by_victimization_1_plot <- plot(joining_by_victimization_1,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.3,0.7),
                               vline = 0.5, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))

#### Atrocity -------------
# anova
cj_anova(reintegration.data, atrocity, by = ~ victimization_1)
# estimation
atrocity_by_victimization_1 <- cj(reintegration.data, atrocity, id = ~respondent, estimate = "mm", by = ~ victimization_1)
atrocity_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
atrocity_by_victimization_1_plot <- plot(atrocity_by_victimization_1,
                                feature_headers = FALSE, 
                                feature_order = c(),
                                legend_pos = "none",
                                xlim = c(0.3,0.7),
                                vline = 0.5, vline_color = "black",
                                size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))

#### Victim/target -------------
# anova
cj_anova(reintegration.data, victim, by = ~ victimization_1)
# estimation
victim_by_victimization_1 <- cj(reintegration.data, victim, id = ~respondent, estimate = "mm", by = ~ victimization_1)
victim_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
victim_by_victimization_1_plot <- plot(victim_by_victimization_1,
                              feature_headers = FALSE, 
                              feature_order = c(),
                              legend_pos = "none",
                              xlim = c(0.3,0.7),
                              vline = 0.5, vline_color = "black",
                              size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))

#### Reason for leaving -------------
# anova
cj_anova(reintegration.data, leaving, by = ~ victimization_1)
# estimation
leaving_by_victimization_1 <- cj(reintegration.data, leaving, id = ~respondent, estimate = "mm", by = ~ victimization_1)
leaving_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
leaving_by_victimization_1_plot <- plot(leaving_by_victimization_1,
                               feature_headers = FALSE, 
                               feature_order = c(),
                               legend_pos = "none",
                               xlim = c(0.3,0.7),
                               vline = 0.5, vline_color = "black",
                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))

#### Confilicatory gestures -------------
# anova
cj_anova(reintegration.data, reconciliation, by = ~ victimization_1)
# estimation
reconciliation_by_victimization_1 <- cj(reintegration.data, reconciliation, id = ~respondent, estimate = "mm", by = ~ victimization_1)
reconciliation_by_victimization_1[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
reconciliation_by_victimization_1_plot <- plot(reconciliation_by_victimization_1,
                                      feature_headers = FALSE, 
                                      feature_order = c(),
                                      legend_pos = "bottom",
                                      legend_title = "By victimization",
                                      xlim = c(0.3,0.7),
                                      xlab = "Conditional marginal means",
                                      vline = 0.5, vline_color = "black",
                                      size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("victimization_1", values = c("Black", "Gray"))
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


### 2.3.4. By Perceived Concern ------------------------------------------------ 

## Recode in Low vs. High concern based on mean value
summary(reintegration.data$worry)
reintegration.data$worrysplit <- NA_real_
reintegration.data$worrysplit[reintegration.data$worry <= -0.009608] <- 0
reintegration.data$worrysplit[reintegration.data$worry > -0.009608] <- 1
reintegration.data$worry <- factor(reintegration.data$worrysplit, 0:1, c("Low", "High"))
summary(reintegration.data$worry)

## All features 
cj_anova(reintegration.data, chosen_model, by = ~ worry)


#### Gender -------------
# anova
cj_anova(reintegration.data, gender, by = ~ worry)
# estimation
gender_by_worry <- cj(reintegration.data, gender, id = ~respondent, estimate = "mm", by = ~ worry)
gender_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
gender_by_worry_plot <- plot(gender_by_worry,
                                       feature_headers = FALSE, 
                                       feature_order = c(),
                                       legend_pos = "none",
                                       xlim = c(0.3,0.7),
                                       vline = 0.5, vline_color = "black",
                                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))

#### Age -------------
# anova
cj_anova(reintegration.data, age, by = ~ worry)
# estimation
age_by_worry <- cj(reintegration.data, age, id = ~respondent, estimate = "mm", by = ~ worry)
age_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
age_by_worry_plot <- plot(age_by_worry,
                                    feature_headers = FALSE, 
                                    feature_order = c(),
                                    legend_pos = "none",
                                    xlim = c(0.3,0.7),
                                    vline = 0.5, vline_color = "black",
                                    size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))

#### Reason for joining -------------
# anova
cj_anova(reintegration.data, joining, by = ~ worry)
# estimation
joining_by_worry <- cj(reintegration.data, joining, id = ~respondent, estimate = "mm", by = ~ worry)
joining_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
joining_by_worry_plot <- plot(joining_by_worry,
                                        feature_headers = FALSE, 
                                        feature_order = c(),
                                        legend_pos = "none",
                                        xlim = c(0.3,0.7),
                                        vline = 0.5, vline_color = "black",
                                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))

#### Atrocity -------------
# anova
cj_anova(reintegration.data, atrocity, by = ~ worry)
# estimation
atrocity_by_worry <- cj(reintegration.data, atrocity, id = ~respondent, estimate = "mm", by = ~ worry)
atrocity_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
atrocity_by_worry_plot <- plot(atrocity_by_worry,
                                         feature_headers = FALSE, 
                                         feature_order = c(),
                                         legend_pos = "none",
                                         xlim = c(0.3,0.7),
                                         vline = 0.5, vline_color = "black",
                                         size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))

#### Victim/target -------------
# anova
cj_anova(reintegration.data, victim, by = ~ worry)
# estimation
victim_by_worry <- cj(reintegration.data, victim, id = ~respondent, estimate = "mm", by = ~ worry)
victim_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
victim_by_worry_plot <- plot(victim_by_worry,
                                       feature_headers = FALSE, 
                                       feature_order = c(),
                                       legend_pos = "none",
                                       xlim = c(0.3,0.7),
                                       vline = 0.5, vline_color = "black",
                                       size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))

#### Reason for leaving -------------
# anova
cj_anova(reintegration.data, leaving, by = ~ worry)
# estimation
leaving_by_worry <- cj(reintegration.data, leaving, id = ~respondent, estimate = "mm", by = ~ worry)
leaving_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
leaving_by_worry_plot <- plot(leaving_by_worry,
                                        feature_headers = FALSE, 
                                        feature_order = c(),
                                        legend_pos = "none",
                                        xlim = c(0.3,0.7),
                                        vline = 0.5, vline_color = "black",
                                        size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))

#### Conciliatory gestures -------------
# anova
cj_anova(reintegration.data, reconciliation, by = ~ worry)
# estimation
reconciliation_by_worry <- cj(reintegration.data, reconciliation, id = ~respondent, estimate = "mm", by = ~ worry)
reconciliation_by_worry[c("level", "estimate", "std.error", "z", "lower", "upper")]
# plot
reconciliation_by_worry_plot <- plot(reconciliation_by_worry,
                                               feature_headers = FALSE, 
                                               feature_order = c(),
                                               legend_pos = "bottom",
                                               legend_title = "By worry",
                                               xlim = c(0.3,0.7),
                                               xlab = "Conditional marginal means",
                                               vline = 0.5, vline_color = "black",
                                               size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")  +
  scale_colour_manual("worry", values = c("Black", "Gray"))


####################### FIGURE 5 ######################
## By Victimization
mm_by_victimization_1 <- plot_grid(age_by_victimization_1_plot +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          joining_by_victimization_1_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          atrocity_by_victimization_1_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          victim_by_victimization_1_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          leaving_by_victimization_1_plot  +
                            theme(axis.title.x = element_blank(),
                                  axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")),
                          reconciliation_by_victimization_1_plot +
                            theme(axis.text.x = element_text(size = 16, colour = "black"),
                                  axis.text.y.left = element_text(size = 16, colour = "black"),
                                  strip.text.y = element_text(size = 16, colour = "black"),
                                  legend.title = element_text(size = 16, colour = "black"),
                                  legend.text = element_text(colour="black", size = 16),
                                  axis.title = element_text(size = 16, colour = "black"),
                                  panel.border = element_rect(fill=NA, colour = "black")), 
                          ncol=1, nrow=6, rel_heights=c(1.2,1,1,1.2,1,1.7), align = "v")
## By Worry 
mm_by_worry <- plot_grid(age_by_worry_plot +
                              theme(axis.title.x = element_blank(),
                                    axis.text.y = element_blank(), axis.ticks.y=element_blank(), 
                                    axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                    strip.text.y = element_text(size = 16, colour = "black"),
                                    panel.border = element_rect(fill=NA, colour = "black")),
                            joining_by_worry_plot +
                              theme(axis.title.x = element_blank(),
                                    axis.text.y = element_blank(), axis.ticks.y=element_blank(),
                                    axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                    strip.text.y = element_text(size = 16, colour = "black"),
                                    panel.border = element_rect(fill=NA, colour = "black")),
                            atrocity_by_worry_plot +
                              theme(axis.title.x = element_blank(),
                                    axis.text.y = element_blank(), axis.ticks.y=element_blank(),
                                    axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                    strip.text.y = element_text(size = 16, colour = "black"),
                                    panel.border = element_rect(fill=NA, colour = "black")),
                            victim_by_worry_plot +
                              theme(axis.title.x = element_blank(),axis.text.y = element_blank(),
                                    axis.ticks.y=element_blank(),
                                    axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                    strip.text.y = element_text(size = 16, colour = "black"),
                                    panel.border = element_rect(fill=NA, colour = "black")),
                            leaving_by_worry_plot +
                              theme(axis.title.x = element_blank(),
                                    axis.text.y = element_blank(), axis.ticks.y=element_blank(),
                                    axis.text.x = element_blank(), axis.ticks.x=element_blank(),
                                    strip.text.y = element_text(size = 16, colour = "black"),
                                    panel.border = element_rect(fill=NA, colour = "black")),
                            reconciliation_by_worry_plot +
                              theme(axis.title = element_text(size = 16, colour = "black"),
                                    axis.text.x = element_text(size = 16, colour = "black"),
                                    axis.text.y.left = element_blank(), axis.ticks.y=element_blank(),
                                    strip.text.y = element_text(size = 16, colour = "black"),
                                    legend.title = element_text(size = 16, colour = "black"),
                                    legend.text = element_text(colour="black", size = 16),
                                    panel.border = element_rect(fill=NA, colour = "black")), 
                            ncol=1, nrow=6, rel_heights=c(1.2,1,1,1.2,1,1.7), align = "v")
## Combine all plot and save in high resolution
jpeg("Figures/figure5.jpeg", width =12, height = 12, units = 'in', res = 300)
grid.arrange(mm_by_victimization_1, mm_by_worry,
             ncol=2,
             widths=c(1.95,1))
dev.off()
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


### 2.3.5. By Features of the Experiment ---------------------------------------

###### Interaction Age and Leaving ######
cj_anova(reintegration.data, chosen ~ Age + Leaving, by = ~ Leaving)

AgeLeaving <- cj(reintegration.data, chosen ~ Age, 
                     id = ~respondent, estimate = "mm", 
                     by = ~Leaving)

AgeLeaving_plot <- plot(AgeLeaving,
                        feature_headers = F,
                        xlim = c(0.2,0.8),
                        vline = 0.5, vline_color = "black",
                        size = 3) + 
  ggplot2::facet_wrap(~Leaving, ncol = 2L) +
  theme(panel.border = element_rect(fill=NA, colour = "black", size = 1),
        axis.text = element_text(size = 13, colour = "black"),
        strip.text = element_text(size = 12, colour = "black"),
        axis.title.x = element_blank(),
        legend.position = c(0.75,0.15),
        legend.text = element_text(size = 11, colour = "black"),    
        legend.box.background = element_rect(color="black", size=1))

####################### FIGURE A7 #####################
jpeg("Figures/SI_figure7.jpeg", width = 8, height = 8.5, units = 'in', res = 300)
AgeLeaving_plot
dev.off()


###### Interaction Age and Reconciliation ######
cj_anova(reintegration.data, chosen ~ Age + Reconciliation, by = ~ Reconciliation)

cj(reintegration.data, chosen ~ Age, id = ~respondent, estimate = "amce", 
   by = ~Reconciliation)[c("BY", "level", "estimate", "std.error", "p")]

AgeReconciliation <- cj(reintegration.data, chosen ~ Age, 
                            id = ~respondent, estimate = "mm", 
                            by = ~Reconciliation)

AgeReconciliation_plot <- plot(AgeReconciliation,
                               feature_headers = F,
                               xlim = c(0.2,0.8),
                               vline = 0.5, vline_color = "black",
                               size = 3) + 
  ggplot2::facet_wrap(~Reconciliation, ncol = 2L) +
  theme(panel.border = element_rect(fill=NA, colour = "black", size = 1),
        axis.text = element_text(size = 13, colour = "black"),
        strip.text = element_text(size = 12, colour = "black"),
        axis.title.x = element_blank(),
        legend.position="bottom",
        legend.text = element_text(size = 11, colour = "black"),
        legend.box.background = element_rect(color="black", size=0.9)) +
  guides(color = guide_legend(nrow = 3))+
  scale_color_discrete(name="Conciliatory\ngestures")

####################### FIGURE A8 #####################
jpeg("Figures/SI_figure8.jpeg", width =8, height =8.5, units = 'in', res = 300)
AgeReconciliation_plot
dev.off()


###### Interaction Joining and Leaving ######
cj_anova(reintegration.data, chosen ~ Joining + Leaving, by = ~ Leaving)

joiningLeaving <- cj(reintegration.data, chosen ~ Joining, 
                     id = ~respondent, estimate = "mm", 
                     by = ~Leaving)

joiningLeaving_plot <- plot(joiningLeaving,
                            feature_headers = F,
                            xlim = c(0.2,0.8),
                            vline = 0.5, vline_color = "black",
                            size = 3) + 
  ggplot2::facet_wrap(~Leaving, ncol = 2L) +
  theme(panel.border = element_rect(fill=NA, colour = "black", size = 1),
        axis.text = element_text(size = 12, colour = "black"),
        strip.text = element_text(size = 12, colour = "black"),
        axis.title.x = element_blank(),
        legend.position = c(0.75,0.15),
        legend.text = element_text(size = 11, colour = "black"),    
        legend.box.background = element_rect(color="black", size=1))

####################### FIGURE A9 #####################
jpeg("Figures/SI_figure9.jpeg", width =8.8, height =8, units = 'in', res = 300)
joiningLeaving_plot
dev.off()


###### Interaction Joining and Reconciliation ######
cj_anova(reintegration.data, chosen ~ Joining + Reconciliation, by = ~ Reconciliation)

joiningReconciliation <- cj(reintegration.data, chosen ~ Joining, 
                     id = ~respondent, estimate = "mm", 
                     by = ~Reconciliation)

joiningReconciliation_plot <- plot(joiningReconciliation,
                                   feature_headers = F,
                                   xlim = c(0.2,0.8),
                                   vline = 0.5, vline_color = "black",
                                   size = 3) + 
  ggplot2::facet_wrap(~Reconciliation, ncol = 2L) +
  theme(panel.border = element_rect(fill=NA, colour = "black", size = 1),
        axis.text = element_text(size = 12, colour = "black"),
        strip.text = element_text(size = 12, colour = "black"),
        axis.title.x = element_blank(),
        legend.position = "bottom",
        legend.text = element_text(size = 10, colour = "black"),
        legend.box.background = element_rect(color="black", size=0.9)) +
  guides(color = guide_legend(nrow = 3))+
  scale_color_discrete(name="Conciliatory\ngestures")

####################### FIGURE A10 #####################
jpeg("Figures/SI_figure10.jpeg", width=8.8, height=8, units = 'in', res = 300)
joiningReconciliation_plot
dev.off()


      

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 3. MODEL DIAGNOSTICS --------------------------------------------------------
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

## 3.1. Randomization and Restrictions ----------------------------------------
## Did the randomization (incl. restrictions) work as intended?

####################### FIGURE A11 #####################
SI_figure11 <- plot(cj_freqs(reintegration.data, chosen_model, id = ~respondent),
                   feature_headers = F,
                   legend_pos = "none") +
  theme(text = element_text(size=12)) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right")
ggsave(filename="Figures/SI_figure11.pdf", 
       plot = SI_figure11, 
       device = cairo_pdf, 
       width = 200, 
       height = 230, 
       units = "mm")
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

## 3.1. Balance Checks --------------------------------------------------------
## Are feature levels well-balanced across our covariates?

# 3.1.1. Region -----------
summary(reintegration_region.data$region)
reintegration_region.data$region_int <- as.integer(reintegration_region.data$region)
reintegration_region.data$region_int
mean(reintegration_region.data$region_int, na.rm = TRUE)
balance_region <- plot(mm(reintegration_region.data, region_int ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation, id = ~respondent),
                         size = 2, 
                         xlim = c(1.15733,  1.35733),
                         vline = mean(reintegration_region.data$region_int, 
                                      na.rm = TRUE),
                         feature_headers = F) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") + ggtitle("Region")
balance_region


# 3.1.2. Religion -----------
summary(reintegration_religion.data$religion)
reintegration_religion.data$religion_int <- as.integer(reintegration_religion.data$religion)
reintegration_religion.data$religion_int
mean(reintegration_religion.data$religion_int, na.rm = T)
balance_religion <- plot(mm(reintegration_religion.data, religion_int ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation, id = ~respondent),
                         size = 2, 
                         xlim = c(1.108057, 1.308057),
                         vline = mean(reintegration_religion.data$religion_int, na.rm = TRUE),
                         feature_headers = F) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") + ggtitle("Religion")
balance_religion


# 3.1.3. Victimization -----------
summary(reintegration.data$victimization_1)
reintegration.data$victim_int <- as.integer(reintegration.data$victimization_1)
reintegration.data$victim_int
mean(reintegration.data$victim_int, na.rm = TRUE)
balance_victim <- plot(mm(reintegration.data, victim_int ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation, id = ~respondent),
                       size = 2, 
                       xlim = c( 1.473085, 1.673085),
                       vline = mean(reintegration.data$victim_int, na.rm = TRUE),
                       feature_headers = F) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") + ggtitle("Victimization")
balance_victim


# 3.1.4. Concern -----------
reintegration.data$worrysplit_int <- as.integer(reintegration.data$worrysplit)
mean(reintegration.data$worrysplit_int)
balance_worry <-plot(mm(reintegration.data, worrysplit_int ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation, id = ~respondent), 
                     size = 2, 
                     xlim = c(0.4816532,0.6816532), 
                     vline = mean(reintegration.data$worrysplit_int, na.rm = TRUE),
                     feature_headers = F) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", strip.position = "right") + ggtitle("Worry")
balance_worry

####################### FIGURE A12 #####################
# clean plots
balance_religion <- balance_religion + theme(
  axis.text.y = element_blank(),
  axis.ticks.y = element_blank(),
  text = element_text(size=10))
balance_region <- balance_region + theme(
  axis.text.y = element_blank(),
  axis.ticks.y = element_blank(),
  text = element_text(size=10))
balance_victim <- balance_victim + theme(
  axis.text.y = element_blank(),
  axis.ticks.y = element_blank(),
  text = element_text(size=10))
balance_worry <- balance_worry + theme(
  axis.text.y = element_blank(),
  axis.ticks.y = element_blank(),
  text = element_text(size=10))
# combine all plots
SI_figure12 <- ggarrange(balance_religion,
                         balance_region, 
                         balance_victim, 
                         balance_worry,
                         nrow = 1, ncol = 4, align = "h",
                         legend = "none",
                         font.label = list(size = 10, 
                                           color = "black", 
                                           face = "bold"))
# save plot
ggsave(filename="Figures/SI_figure12.pdf", 
       plot = SI_figure12, 
       device = cairo_pdf, 
       width = 220, 
       height = 200, 
       units = "mm")
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

## 3.3. Carryover Assumption ---------------------------------------------------
## Are there substantial variations in preferences within-respondents 
## across multiple conjoint decision tasks?

chosen_model <- chosen ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation
cj_anova(reintegration.data, chosen_model, by = ~ task)


## 3.4. Profile-Order Assumption -----------------------------------------------
## Are there substantial variations in preferences within-respondents 
## depending on the left or right-hand profile?

chosen_model <- chosen ~ Gender + Age * Joining + Atrocity * Victim + Leaving + Reconciliation
cj_anova(reintegration.data, chosen_model, by = ~profile)

####################### FIGURE A13 #####################
# AMCE plot by profile
amce_by_profile <- plot(cj(reintegration.data, 
                           chosen_model, id = ~respondent, 
                           by = ~profile, estimate = "amce"), 
                        group = "profile",
                        vline = 0, 
                        feature_headers = F, 
                        size = 2, 
                        xlim = c(-0.15,0.4)) +
  ggplot2::facet_wrap(~feature, ncol = 1L, 
                      scales = "free_y", 
                      strip.position = "right")
# MM plot by profile
mm_by_profile <- plot(cj(reintegration.data, 
                         chosen_model, id = ~respondent, 
                         by = ~profile, estimate = "mm"), 
                      group = "profile", 
                      vline = 0.5, 
                      feature_headers = F, 
                      size = 2, 
                      xlim = c(0.3,0.7)) +
  ggplot2::facet_wrap(~feature, ncol = 1L, 
                      scales = "free_y", 
                      strip.position = "right") 
# clean both plots
amce_by_profile <- amce_by_profile +
  theme(axis.title.x = element_text(size = 12, colour = "black"), 
        axis.text.x = element_text(size = 10, colour = "black"),
        axis.text.y =  element_text(size = 12, colour = "black"), 
        strip.text.y = element_text(size = 12, colour = "black"), 
        panel.border = element_rect(fill=NA, colour = "black"))
mm_by_profile <- mm_by_profile + 
  theme(axis.title.x = element_text(size = 12, colour = "black"),
        axis.text.x = element_text(size = 10, colour = "black"),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.y = element_blank(),
        strip.text.y = element_text(size = 12, colour = "black"), 
        panel.border = element_rect(fill=NA, colour = "black")) 
# combine both plots
SI_figure13 <- ggarrange(amce_by_profile, mm_by_profile, 
                        nrow = 1, ncol = 2,
                        widths=c(2,.9),
                        font.label = list(size = 12, color = "black", face = "bold", family = NULL))
# save plot
ggsave(filename="Figures/SI_figure13.pdf", 
       plot = SI_figure13, 
       device = cairo_pdf, 
       width = 200, 
       height = 270, 
       units = "mm")


## 4. ROBUSTNESS CHECK (victimization) -----------------------------------------

####################### FIGURE A16 #####################
# create dichotomous indicator
summary(as.factor(reintegration.data$TES))
reintegration.data$exposure <- NA_real_
reintegration.data$exposure[reintegration.data$TES == 0] <- 0
reintegration.data$exposure[reintegration.data$TES > 0] <- 1
reintegration.data$exposure <- factor(reintegration.data$exposure, 0:1, 
                                      c("Not Exposed", "Exposed"))
summary(reintegration.data$exposure)

## check conditional mm's
chosen_mm_by_exposure <- cj(reintegration.data, 
                            chosen_model, id = ~respondent, 
                            estimate = "mm", by = ~exposure)
cj_anova(reintegration.data, chosen_model, by = ~ exposure) # formal test

# plot Marginal Means for both groups based on exposure to violence
chosen_mm_by_exposure_plot <- plot(chosen_mm_by_exposure,
                                   feature_headers = F, 
                                   feature_order = c(),
                                   legend_pos = "bottom",
                                   legend_title = "By Exposure",
                                   xlim = c(0.3,0.7),
                                   xlab = "Conditional Marginal Means",
                                   vline = 0.5, vline_color = "black",
                                   size = 3) +
  ggplot2::facet_wrap(~feature, ncol = 1L,
                      scales = "free_y", 
                      strip.position = "right") +
  scale_colour_manual("exposure", values = c("Black", "Gray"))
# clean plot
chosen_mm_by_exposure_plot <- chosen_mm_by_exposure_plot +
  theme(axis.text.y =  element_text(size = 14, colour = "black"), 
        strip.text.y = element_text(size = 14, colour = "black"),
        legend.text = element_text(size = 14, colour = "black"),
        panel.border = element_rect(fill=NA, colour = "black")) 
# save plot
ggsave(filename="Figures/SI_figure16.pdf", 
       plot = chosen_mm_by_exposure_plot, 
       device = cairo_pdf, 
       width = 200, 
       height = 270, 
       units = "mm")
